netapp_ontap.models.application_protection_groups_rpo API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_protection_groups_rpo`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationProtectionGroupsRpoSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationProtectionGroupsRpo object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `local GET POST PATCH`

    The local field of the application_protection_groups_rpo.

  `remote GET POST PATCH`

    The remote field of the application_protection_groups_rpo.